############
Contributors
############

Here is an alphabetically-ordered list of the people who
contributed to this software in one way or another.

* Andreas Motl <andreas@hiveeyes.org>
* Carolin Johannsen <caro@hiverize.org>
* Clemens Gruber <clemens@hiveeyes.org>
* Diedrich Lamken <didi@hiverize.org>
* Diren Senger <diren@uni-bremen.de>
* Dominik Kapusta <https://github.com/ayoy>
* Ingo Porzucek <https://community.hiveeyes.org/u/ingop/>
* Jan Hoffmann <j.hoffmann@isarengineering.de>
* Kolja <https://github.com/pinguin999>
* Markus Mohr <https://github.com/poesel>
* Matthias Büchner <https://github.com/thiasB>
* Matthias Mehldau <wetter@hiveeyes.org>
* Michael Kurzweil <https://flowers4bees.org/>
* Ralf Lindlein <https://github.com/walterheisenberg>
* Richard Pobering <richard@hiveeyes.org>
* Roh <https://community.hiveeyes.org/u/roh/>
* Ron Jacob <ron.jacob@easyhive.org>
* Thorsten Kluß <https://community.hiveeyes.org/u/tox/>
* Vincent Kuhlen <vkuhlen@uni-bremen.de>
* Weef <https://community.hiveeyes.org/u/weef/>
* Werner Sturm <wernersturm89@gmail.com>

Thanks a bunch!


****************
Acknowledgements
****************
This program would not have been possible without all the amazing work
people are doing on the foundation infrastructure the software is leveraging.

- Damien George, Paul Sokolovsky, Dave Hylands, @stinos and all other
  `MicroPython core developers`_ and `micropython-lib`_ authors.
- Paul Sokolovsky for improving MicroPython through the Pycopy fork.
- All contributors to `pycom-micropython-sigfox`_ and `pycom-libraries`_.
- Daniel Campora for the Pycom MQTT package.
- David Gerber <https://github.com/geda>, Robert H. <https://github.com/robert-hh> and
  Anthony Hinsinger <https://github.com/atoy40> for the HX711 driver.
- Robert H. <https://github.com/robert-hh> for the 1-Wire and DS18B20 drivers,
  the BME280 driver and many important details we learned from him through the
  `Pycom user forum`_.
- Paweł Zadrożny <https://github.com/pawelzny> for the `Dotty Dict`_ package.
- Sebastian Meiling <https://github.com/smlng> for the ``PyCayenneLPP`` package.
- Dominik Kapusta <https://github.com/ayoy> for many inspirations
  from the `upython-aq-monitor`_.

Thank you so much for providing such great infrastructure
components and resources to the community! You know who you are.

.. _MicroPython core developers: https://github.com/micropython/micropython/graphs/contributors
.. _micropython-lib: - https://github.com/micropython/micropython-lib
.. _pycom-micropython-sigfox: https://github.com/pycom/pycom-micropython-sigfox
.. _pycom-libraries: https://github.com/pycom/pycom-libraries
.. _upython-aq-monitor: https://github.com/ayoy/upython-aq-monitor
.. _Dotty Dict: https://github.com/pawelzny/dotty_dict
.. _Pycom user forum: https://forum.pycom.io/


**********
Foundation
**********
This is a reference list of things this program is and will partly be based upon:

- https://github.com/pycom/pycom-libraries
- https://github.com/micropython/micropython-lib
- https://github.com/daq-tools/terkin/tree/master/src/micropython
- The RaTrack firmware (undisclosed yet)
- https://github.com/microhomie/microhomie
- https://github.com/ClemensGruber
- https://github.com/hiveeyes/arduino
- https://github.com/jacobron/EasyHive_Pycom_Shield/tree/master/V1.0/software
- https://github.com/walterheisenberg/hivewatch_esp32
- https://github.com/Quernon/honeypi
- https://github.com/geda/hx711-lopy

Standing on the shoulders of giants. Thank you so much!
